"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.help = exports.commandNames = exports.cliOptionsTypes = exports.rcOptionsTypes = void 0;
const path_1 = __importDefault(require("path"));
const cli_utils_1 = require("@pnpm/cli-utils");
const config_1 = require("@pnpm/config");
const store_connection_manager_1 = require("@pnpm/store-connection-manager");
const parse_wanted_dependency_1 = __importDefault(require("@pnpm/parse-wanted-dependency"));
const pick_js_1 = __importDefault(require("ramda/src/pick.js"));
const pick_registry_for_package_1 = __importDefault(require("@pnpm/pick-registry-for-package"));
const render_help_1 = __importDefault(require("render-help"));
const tempy_1 = __importDefault(require("tempy"));
exports.rcOptionsTypes = cliOptionsTypes;
function cliOptionsTypes() {
    return (0, pick_js_1.default)([], config_1.types);
}
exports.cliOptionsTypes = cliOptionsTypes;
exports.commandNames = ['patch'];
function help() {
    return (0, render_help_1.default)({
        description: 'Prepare a package for patching',
        descriptionLists: [],
        url: (0, cli_utils_1.docsUrl)('patch'),
        usages: ['pnpm patch'],
    });
}
exports.help = help;
async function handler(opts, params) {
    const store = await (0, store_connection_manager_1.createOrConnectStoreController)({
        ...opts,
        packageImportMethod: 'clone-or-copy',
    });
    const dep = (0, parse_wanted_dependency_1.default)(params[0]);
    const pkgResponse = await store.ctrl.requestPackage(dep, {
        downloadPriority: 1,
        lockfileDir: opts.dir,
        preferredVersions: {},
        projectDir: opts.dir,
        registry: (dep.alias && (0, pick_registry_for_package_1.default)(opts.registries, dep.alias)) ?? opts.registries.default,
    });
    const filesResponse = await pkgResponse.files();
    const tempDir = tempy_1.default.directory();
    const userChangesDir = path_1.default.join(tempDir, 'user');
    await Promise.all([
        store.ctrl.importPackage(path_1.default.join(tempDir, 'source'), {
            filesResponse,
            force: true,
        }),
        store.ctrl.importPackage(userChangesDir, {
            filesResponse,
            force: true,
        }),
    ]);
    return `You can now edit the following folder: ${userChangesDir}`;
}
exports.handler = handler;
//# sourceMappingURL=patch.js.map